<!-- Logo ------------------------------------------->
<h4 align="center">
    <img src="https://github.com/zoeyzyhu/pybind_cmake_simple/raw/main/logo_tr_git.png" alt="Pydisort" width="300" style="display: block; margin: 0 auto">
</h4>

<!-- Subtitle --------------------------------------->
<p align="center">
  <i align="center">Empower Discrete Ordinates Radiative Transfer (DISORT) with Python 🚀</i>
</p>

## <a id='about-pydisort'> About Pydisort </a>

DISORT (Discrete Ordinate Radiative Transfer) is a widely-used algorithm that calculates the scattering and absorption of radiation in a medium. The original DISORT algorithm was developed by Stamnes et al. in 1988 and was implemented in `FORTRAN`. `pydisort` is a Python wrapper for the DISORT algorithm in `C`. The wrapper is designed to be simple and easy to use. It is also designed to be flexible and extensible.

For a detailed documentation, please visit https://pydisort.readthedocs.io/.

> ❗ We only support Python 3.6+ on Linux and Python 3.8+ on MacOS. Anaconda is not fully supported at the moment; it only works if the Python path and `conda` environment are set correctly. For the current stage, we strongly recommend using `python3.11 -m venv env` (you Python version might differ) to create a virtual environment and install `pydisort` in this clean environment.
